pub fn process_stamp() -> u64Expand description
Per-process stamp: the low bits of the wall clock at first use. Not a security token – it only needs to differ between restarts.
Public because frink-server’s conversation ids need the same
stamp for the same reason, and had a byte-identical copy of this
function whose doc comment said it was mirroring this one. A copy
that says it is a copy is still a copy.